Name: mMass
Summary: Open Source Mass Spectrometry Tool
Version: 5.5.0
Release: 5%{?dist}
License: GPLv3+
Group:   Applications/Engineering
URL: http://www.mmass.org/
Source0: http://www.mmass.org/download/files/v%{version}/mmass_v%{version}_source.zip

## Database links
Source1: http://www.mmass.org/download/files/compounds/compounds_lipidmaps.zip
Source2: http://www.mmass.org/download/files/compounds/compounds_norine.zip
Source3: http://www.mmass.org/download/files/compounds/compounds_fungal_peptides.zip

## Example links
Source4: http://www.mmass.org/download/files/examples/examples_general.zip
Source5: http://www.mmass.org/download/files/examples/examples_hdx.zip
Source6: http://www.mmass.org/download/files/examples/examples_cpeptides.zip

Source7: %{name}.desktop

BuildRequires: python2-devel, desktop-file-utils 
BuildRequires: python-libs
BuildRequires: wxPython-devel, numpy
BuildRequires: dos2unix

%description
Open Source Mass Spectrometry Tool

%package examples
Summary: %{name} examples
Group: Applications/Engineering
Requires: %{name} = %{version}-%{release}
BuildArch: noarch
%description examples
%{name} examples data.

%package doc
Summary: %{name} documentation
Group: Applications/Engineering
BuildArch: noarch
%description doc
%{name} PDF User Guide.

%prep
%setup -q -n %{name}
mv readme.txt README.txt
rm mspy/calculations.so setup.py

sed -i 's/\r$//' license.txt

## Fix wrong-script-end-of-line-encoding error
dos2unix mspy/plot_canvas.py 

## Add Python shebang 
sed -i -e '1i#!/usr/bin/python' gui/*.py
sed -i -e '1i#!/usr/bin/python' mspy/*.py

## Unpacking zipped databases 
unzip %{SOURCE1}
mv LIPIDMAPS/readme.txt LIPIDMAPS/lipidmaps-readme.txt
rm -rf  __MACOSX

unzip %{SOURCE2} 
mv readme.txt norine-readme.txt

unzip %{SOURCE3}
mv readme.txt fungal_peptides-readme.txt

## Unpacking zipped examples and
## removing all useless/proprietary files
unzip %{SOURCE4}
rm -rf __MACOSX

unzip %{SOURCE5}
rm -rf __MACOSX

unzip %{SOURCE6}
rm -rf __MACOSX

%build
## Need just build 'calculations' extension
pushd mspy
CFLAGS="$RPM_OPT_FLAGS" %{__python} setup.py build
mv -f build/lib.*/calculations.so ./calculations.so
popd

%install
pushd mspy
%{__python} setup.py install --skip-build --root $RPM_BUILD_ROOT
popd 

## Making installation directories
mkdir -p $RPM_BUILD_ROOT%{_libdir}/%{name}
mkdir -p $RPM_BUILD_ROOT%{_libdir}/%{name}/configs
mkdir -p $RPM_BUILD_ROOT%{_datadir}/%{name}/database
mkdir -p $RPM_BUILD_ROOT%{_datadir}/%{name}/examples
mkdir -p $RPM_BUILD_ROOT%{_datadir}/applications
mkdir -p $RPM_BUILD_ROOT%{_libdir}/%{name}/mspy
mkdir -p $RPM_BUILD_ROOT%{_libdir}/%{name}/gui/images/gtk
mkdir -p $RPM_BUILD_ROOT%{_bindir}

## Removing useless files
rm mspy/setup.py
rm mspy/*.pyd

## Allocating all files
install -p -m 755 mspy/*.py* $RPM_BUILD_ROOT%{_libdir}/%{name}/mspy
install -p -m 755 mspy/*.so $RPM_BUILD_ROOT%{_libdir}/%{name}/mspy
install -p -m 644 configs/*.xml $RPM_BUILD_ROOT%{_libdir}/%{name}/configs
install -p -m 755 gui/*.py* $RPM_BUILD_ROOT%{_libdir}/%{name}/gui
install -p -m 644 gui/images/gtk/*.png $RPM_BUILD_ROOT%{_libdir}/%{name}/gui/images/gtk
install -p -m 755 mmass.py* $RPM_BUILD_ROOT%{_libdir}/%{name}
install -p -m 644 *.xml $RPM_BUILD_ROOT%{_datadir}/%{name}/database
install -p -m 644 General*Examples/*.msd HDX*Examples/*.msd Cyclic*Peptide*Examples/*.msd $RPM_BUILD_ROOT%{_datadir}/%{name}/examples

desktop-file-install                           \
 --dir=$RPM_BUILD_ROOT%{_datadir}/applications \
%{SOURCE7}

## Making binary file to start mMass

cat <<EOF > mmass
#!/bin/bash
(
 cd %{_libdir}/%{name}
 %{__python} mmass.py
)
EOF

## Move mMass binary in /usr/bin directory 
## and make it executable
install -m 755 mmass $RPM_BUILD_ROOT%{_bindir}

## Add Python shebang
sed -i -e '1i#!/usr/bin/python' $RPM_BUILD_ROOT%{_libdir}/%{name}/mmass.py

%files
%doc license.txt README.txt *-readme.txt
%{_bindir}/mmass
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/mmass.py*
%dir %{_libdir}/%{name}/configs
%{_libdir}/%{name}/configs/*.xml
%dir %{_libdir}/%{name}/mspy
%{_libdir}/%{name}/mspy/*.py*
%{_libdir}/%{name}/mspy/*.so
%dir %{_libdir}/%{name}/gui
%{_libdir}/%{name}/gui/*
%{python_sitearch}/*.egg-info
%{_datadir}/%{name}/database/
%{_datadir}/applications/*.desktop 

%files examples
%{_datadir}/%{name}/examples/

%files doc
%doc *Guide.pdf license.txt 


%changelog
* Tue Nov 19 2013 Antonio Trande <sagitter@fedoraproject.org> 5.5.0-5
- Update LIPID MAPS Database (November 16, 2013)
- User Guide packaged in the .doc subpackage
- Installed new .desktop file

* Tue Sep 17 2013 Antonio Trande <sagitter@fedoraproject.org> 5.5.0-4
- Fixed shebang and wrong-script-end-of-line-encoding  errors
- Added BR dos2unix
- Subpackage database built in main package

* Fri Sep 13 2013 Antonio Trande <sagitter@fedoraproject.org> 5.5.0-3
- examples and database directories are now owned by package
- Set compiler flags
- Main software files now are placed in %%{_libdir}/%%{name}

* Fri Sep 13 2013 Antonio Trande <sagitter@fedoraproject.org> 5.5.0-2
- Python shebang addendum moved to %%prep section
- Use macros in the 'mmass' file creation

* Tue Aug 27 2013 Antonio Trande <sagitter@fedoraproject.org> 5.5.0-1
- Initial build
- 'calculations.so' library destination changed to 'mspy' subdirectory
- Created a 'mmass' binary file 
- Added commands to remove all useless/proprietary/hidden files
